function [ber] = ds_cdma(snr_db,K,Ntr)
%  Simulation code for DS-CDMA system using the matched-filter detector 
%
%  January 2007
%  Author: Rodrigo C. de Lamare
%-------------------------------------------------------------------
% Parameters

%Processing gain
N = 16;

% Spreading sequences
S = sign(randint(N,K)-0.5);      
S = S/sqrt(N); % normalization

% Symbol energy of users (equals the amplitude)
E = ones(K,1);

% Signal-to-noise-ratio (SNR)
snr = exp(snr_db*log(10)/10);
sigma = E(1)/sqrt(snr); % first user

% Counter for number of errors
nbe = 0; % first user


for l = 1 : Ntr
    % memory allocation for the composite signal x
    x = zeros(N,1);
    
    % symbols
    b = sign(randint(K,1)-0.5);
    
    % generation of the composite signal x with K users
    for i = 1:K
        x = x + sqrt(E(i))*b(i)*S(:,i);  
    end

    % noise at the receiver
    n = (sigma/sqrt(2))*randn(N,1);
    
    % received data
    r = x + n;
    
    % matched-filter detector output (user 1)
    z = S(:,1)'*r;
    
    % detection
    dec = sign(real(z));
    
    % counting errors
    if (dec ~= b(1))
        nbe = nbe + 1;   
    end   
end

% bit error rate computation
ber = nbe/Ntr;


